#!/usr/bin/env Rscript

suppressPackageStartupMessages({
  if (!require("pacman")) install.packages("pacman")
  pacman::p_load(tidyverse, here, forcats, reshape2, scales)
})

source(here("processing_config.R"))

aucs <- read_tsv(paste0(output_data_path, "aucs_pv.tsv"), col_types = cols())

aucs <- aucs %>% mutate(control_ = recode(control,
  CONTROL = "untreated",
  `control drug` = "reference compounds",
  `other drug` = "other drugs"),
  control_ = fct_rev(control_))

p <- ggplot(aucs, aes(pv)) + geom_histogram(boundary = 0, bins = 50) + facet_wrap(~control_, ncol = 1, scales = "free_y") +
  xlab("p-value") + ylab("count of replicate-compound pairs") + scale_x_continuous(expand=c(0,0), breaks=c(0, 0.5, 1)) +
  scale_y_continuous(breaks = pretty_breaks(2)) +
   theme_minimal() + theme(strip.background = element_rect(fill="lightgrey", color="lightgrey", size=0),
                           axis.title = element_text(size = 7), axis.text = element_text(size = 6),
                           strip.text = element_text(size = 7), panel.grid.minor.y = element_blank())

ggsave("figure_pdf/figED2d_pvalue_distribution.pdf", width = 10, height = 7, units = "cm")

getCorr <- function(x) {
  m <- x %>% acast(prestwick_ID~replicate_id, value.var = "normAUC")
  mc <- cor(m, use="p", method="p")
  tibble(corr = mc[ upper.tri(mc) ])
}

all_corr <- aucs %>% filter(control != "CONTROL") %>% group_by(NT_code) %>% do(getCorr(.))

# number for paper
median(all_corr$corr)

ggplot(all_corr, aes(corr)) + geom_histogram(boundary = 1, binwidth = 0.05) +
  geom_vline(xintercept = median(all_corr$corr)) +
  xlab("Pearson correlation between AUCs within strains") + ylab("count") +
  scale_x_continuous(expand=c(0,0)) +
  scale_fill_manual(values = c("#aaaaaa", "#555555")) +
  theme_minimal() + theme(axis.title = element_text(size = 7), axis.text = element_text(size = 6),
                          panel.grid.minor = element_blank())

ggsave("figure_pdf/figED2c_QC_replicate_correlations.pdf", width = 10, height = 3, units = "cm")
