#!/usr/bin/env Rscript

suppressPackageStartupMessages({
  if (!require("pacman")) install.packages("pacman")
  pacman::p_load(readxl, tidyverse, stringi, forcats)
})

source("processing_config.R")

strain_level <- read_excel("annotations/nm.4345-S4.xlsx", "Sheet1", na = "NS")

species_annotations <- read_tsv("annotations/species_annotations.tsv") %>%
  mutate(species = stri_replace_all_regex(Species, "^([^ ]+ [^ ]+).*", "$1")) %>%
  select(NT_code, species, Genus)

MICs <- read_tsv(paste0(output_data_path, "LM16-121_142-MIC.tsv"))
MICs <- MICs %>% filter(prestwick_ID == "Prestw-4")

strain_level <- strain_level %>% mutate(species = stri_replace_all_regex(`Bacterial Strains`, "^([^ ]+ [^ ]+).*", "$1"))
strain_level <- strain_level %>% inner_join(species_annotations, by = "species")

strain_level <- bind_rows(
  strain_level %>%
    select(species, NT_code, log2FoldChange.M2, pvalue.M2, FDR.M2) %>%
    mutate(time = "M2") %>%
    rename(log2FoldChange = log2FoldChange.M2, pvalue = pvalue.M2, FDR = FDR.M2),
  strain_level %>%
    select(species, NT_code, log2FoldChange.M4, pvalue.M4, FDR.M4) %>%
    mutate(time = "M4") %>%
    rename(log2FoldChange = log2FoldChange.M4, pvalue = pvalue.M4, FDR = FDR.M4),
  strain_level %>%
    select(species, NT_code, `log2FoldChange.P/M6`, `pvalue.P/M6`, `FDR.P/M6`) %>%
    mutate(time = "M6") %>%
    rename(log2FoldChange = `log2FoldChange.P/M6`, pvalue = `pvalue.P/M6`, FDR = `FDR.P/M6`)
)

strain_level <- strain_level %>% left_join(MICs, by = "NT_code")

strain_level %>% filter(!is.na(log2FoldChange), !is.na(Conc)) %>%
  mutate(species = fct_reorder(species, Conc)) %>%
  ggplot(aes(Conc, log2FoldChange, color = time, shape = species)) +
  geom_point() +
  scale_x_log10() +
  theme_minimal() +
  scale_shape(name = "Species") +
  scale_color_discrete(name = "Time point") +
  xlab(expression(IC[25]*" per strain (µM)")) + ylab("Change in relative abdunandance\nupon treatment (log 2 fold change)") +
  theme(axis.text = element_text(size = 6), legend.text = element_text(size = 6),
        axis.title = element_text(size = 7), legend.title = element_text(size = 7),
        legend.position = "bottom", legend.direction = "vertical",
        legend.key.height = unit(0.8, units = "line"))

ggsave("figure_pdf/figED4b_metformin_concordance.pdf", units = "cm", height = 9, width = 8)


